@@ -1,20 +1,11 @@
-/*************************************************************************
- *  Copyright (C) 2008, 2009, 2010 by Volker Lanz <vl@fidra.de>          *
- *  Copyright (C) 2016-2018 by Andrius Štikonas <andrius@stikonas.eu>    *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2009 Andrew Coles <andrew.i.coles@googlemail.com>
+    SPDX-FileCopyrightText: 2014-2020 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2018 Huzaifa Faruqui <huzaifafaruqui@gmail.com>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "jobs/job.h"
 
@@ -100,17 +91,17 @@ bool Job::rollbackCopyBlocks(Report& report, CopyTarget& origTarget, CopySource&
 
 void Job::emitProgress(int i)
 {
-    emit progress(i);
+    Q_EMIT progress(i);
 }
 
-void Job::updateReport(const QVariantMap& reportString)
+void Job::updateReport(const QString& report)
 {
-    m_Report->line() << reportString[QStringLiteral("report")].toString();
+    m_Report->line() << report;
 }
 
 Report* Job::jobStarted(Report& parent)
 {
-    emit started();
+    Q_EMIT started();
 
     return parent.newChild(xi18nc("@info:progress", "Job: %1", description()));
 }
@@ -118,8 +109,8 @@ Report* Job::jobStarted(Report& parent)
 void Job::jobFinished(Report& report, bool b)
 {
     setStatus(b ? Status::Success : Status::Error);
-    emit progress(numSteps());
-    emit finished();
+    Q_EMIT progress(numSteps());
+    Q_EMIT finished();
 
     report.setStatus(xi18nc("@info:progress job status (error, warning, ...)", "%1: %2", description(), statusText()));
 }
